<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About MystiQ</source>
        <translation>A MystiQ-ről</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Információ</translation>
    </message>
    <message>
        <source>Translators</source>
        <translation>Fordítók</translation>
    </message>
    <message>
        <source>Portable</source>
        <translation>Szállítható</translation>
    </message>
    <message>
        <source>Compiled with Qt %1</source>
        <translation>Fordítva Qt %1 verzióval</translation>
    </message>
    <message>
        <source>Compiled with libnotify %1</source>
        <translation>Fordítva libnotify %1 verzióval</translation>
    </message>
    <message>
        <source>MystiQ Homepage: %1</source>
        <translation>MystiQ honlap: %1</translation>
    </message>
    <message>
        <source>Some audio-processing functionalities are provided by SoX.</source>
        <translation>Néhány audió feldolgozó funkciót a SoX biztosít.</translation>
    </message>
    <message>
        <source>Spanish (Spain)</source>
        <extracomment>Spanish Language (Spain)</extracomment>
        <translation>Spanyol</translation>
    </message>
    <message>
        <source>License</source>
        <translation>Engedély</translation>
    </message>
    <message>
        <source>MystiQ is a GUI frontend for FFmpeg.</source>
        <translation>A MystiQ egy grafikus felhasználói felület az FFmpeg számára.</translation>
    </message>
    <message>
        <source>Developers:&lt;br&gt; %1</source>
        <translation>Fejlesztők: &lt;br&gt; %1</translation>
    </message>
    <message>
        <source>Application Name:&lt;br&gt; %1</source>
        <translation>Alkalmazás neve: &lt;br&gt; %1</translation>
    </message>
    <message>
        <source>Swedish (Sweden)</source>
        <extracomment>Swedish Language (Sweden)</extracomment>
        <translatorcomment>Svéd nyelv (Svédország)</translatorcomment>
        <translation>Svéd (Svédország)</translation>
    </message>
    <message>
        <source>Japanese (Japan)</source>
        <extracomment>Japanese Language (Japan)</extracomment>
        <translatorcomment>Japán nyelv (Japán)</translatorcomment>
        <translation>Japán (japán)</translation>
    </message>
    <message>
        <source>German (Germany)</source>
        <extracomment>German Language (Germany)</extracomment>
        <translatorcomment>Német nyelv (Németország)</translatorcomment>
        <translation>Német (Németország)</translation>
    </message>
    <message>
        <source>Italian (Italy)</source>
        <extracomment>Italian Language (Italy)</extracomment>
        <translatorcomment>Olasz nyelv (Olaszország)</translatorcomment>
        <translation>Olasz (Olaszország)</translation>
    </message>
    <message>
        <source>This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License version 3.</source>
        <translation>Ez a program egy ingyenes szoftver; újraterjesztheti és / vagy módosíthatja a GNU General Public License 3. verziójának feltételei szerint.</translation>
    </message>
    <message>
        <source>Turkish (Turkey)</source>
        <extracomment>Turkish Language (Turkey)</extracomment>
        <translatorcomment>Török nyelv (Törökország)</translatorcomment>
        <translation>Török (Törökország)</translation>
    </message>
    <message>
        <source>Many people have contributed translations. You can also help translate the MystiQ Video Converter into your own language. Visit </source>
        <translation>Sokan hozzájárultak a fordításokhoz. Segíthet a MystiQ Video Converter saját nyelvére történő fordításában is. Látogatás </translation>
    </message>
    <message>
        <source> and join a translation team.</source>
        <translation> és csatlakozzon egy fordító csoporthoz.</translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation>Változási napló</translation>
    </message>
    <message>
        <source>Hungarian (Hungary)</source>
        <extracomment>Hungarian Language (Hungary)</extracomment>
        <translatorcomment>Magyar nyelv (Magyarország)</translatorcomment>
        <translation>Magyar (Magyarország)</translation>
    </message>
    <message>
        <source>Russian (Russia)</source>
        <extracomment>Russian Language (Russia)</extracomment>
        <translatorcomment>Orosz nyelv (Oroszország)</translatorcomment>
        <translation>Orosz (Oroszország)</translation>
    </message>
    <message>
        <source>Collaborators:&lt;br&gt; %1</source>
        <translation>Együttműködők: &lt;br&gt; %1</translation>
    </message>
    <message>
        <source>Some features of MystiQ Video Converter have been inspired by</source>
        <translation>A MystiQ Video Converter néhány funkcióját az ihlette</translation>
    </message>
    <message>
        <source>Galician (Galicia)</source>
        <extracomment>Galician Language (Galicia)</extracomment>
        <translatorcomment>Galíciai nyelv (Galícia)</translatorcomment>
        <translation>Galíciai (Galícia)</translation>
    </message>
    <message>
        <source>Icons Theme:&lt;br&gt; %1</source>
        <translation>Ikonok téma: &lt;br&gt; %1</translation>
    </message>
    <message>
        <source>Indonesian (Indonesia)</source>
        <extracomment>Indonesian Language (Indonesia)</extracomment>
        <translatorcomment>Indonéz nyelv (Indonézia)</translatorcomment>
        <translation>Indonéz (Indonézia)</translation>
    </message>
</context>
<context>
    <name>AboutFFmpegDialog</name>
    <message>
        <source>About FFmpeg</source>
        <translation>Az FFmpeg-ről</translation>
    </message>
    <message>
        <source>FFmpeg</source>
        <translation>FFmpeg</translation>
    </message>
    <message>
        <source>Available Codecs</source>
        <translation>Elérhető kodekek</translation>
    </message>
    <message>
        <source>FFmpeg is a complete, cross-platform solution to record, convert and stream audio and video. It includes libavcodec - the leading audio/video codec library.</source>
        <extracomment>ffmpeg description</extracomment>
        <translatorcomment>ffmpeg leírása</translatorcomment>
        <translation>Az FFmpeg teljes körű, keresztplatfomos megoldás videó- és hangfájlok felvételére, átalakítására és továbbítására, mely tartalmazza a vezető audio/video könytárat, a libavcodec-et.</translation>
    </message>
    <message>
        <source>FFmpeg is free software licensed under the LGPL or GPL.</source>
        <translation>Az FFmpeg szabad szoftver. Licensze: LGPL vagy GPL.</translation>
    </message>
    <message>
        <source>Please visit %1 for more information.</source>
        <translation>További információért látogassa meg a honlapot: %1.</translation>
    </message>
</context>
<context>
    <name>AddTaskWizard</name>
    <message>
        <source>Add Tasks</source>
        <translation>Feladat hozzáadása</translation>
    </message>
    <message>
        <source>Files to be converted</source>
        <translation>Átalakítandó fájlok</translation>
    </message>
    <message>
        <source>Add files.</source>
        <translation>Fájlok hozzáadása.</translation>
    </message>
    <message>
        <source>Remove selected files.</source>
        <translation>Kiválasztott fájlok eltávolítása.</translation>
    </message>
    <message>
        <source>Output Settings</source>
        <translation>Kimeneti beállítások</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Szerkesztés</translation>
    </message>
    <message>
        <source>Auto adjust output bitrate to reduce output file size.</source>
        <translation>A kimeneti bitráta automatikus beállítása a fájlméret csökkentése érdekében.</translation>
    </message>
    <message>
        <source>Auto Adjust Audio Bitrate</source>
        <translation>Audio bitráta automatikus beállítása</translation>
    </message>
    <message>
        <source>Preset</source>
        <translation>Előbeállítás</translation>
    </message>
    <message>
        <source>Convert to</source>
        <translation>Átalakítás ebbe</translation>
    </message>
    <message>
        <source>Output Path</source>
        <translation>Kimeneti elérési út</translation>
    </message>
    <message>
        <source>Select &amp;folder</source>
        <translation>Mappa &amp;Kiválasztása</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Böngészés</translation>
    </message>
    <message>
        <source>Create &amp;new folder in source folder</source>
        <extracomment>Create a new folder (e.g. mystiq_output) in the folder containing the input files. Put the output files in the newly created folder.</extracomment>
        <translatorcomment>Hozzon létre egy új mappát (például mystiq_output) a bemeneti fájlokat tartalmazó mappába. Helyezze a kimeneti fájlokat az újonnan létrehozott mappába.</translatorcomment>
        <translation>Új mappa &amp;létrehozása a bemeneti fájlok mappájában</translation>
    </message>
    <message>
        <source>Folder Name</source>
        <translation>Mappa neve</translation>
    </message>
    <message>
        <source>Output to &amp;source folder</source>
        <extracomment>put the output files in the same folder as the input files</extracomment>
        <translatorcomment>tegye a kimeneti fájlokat ugyanabba a mappába, mint a bemeneti fájlokat</translatorcomment>
        <translation>&amp;Kimeneti fájlok a forrás mappába</translation>
    </message>
    <message>
        <source>Please select at least one file.</source>
        <translation>Legalább egy fájlt válasszon ki.</translation>
    </message>
    <message>
        <source>Select Files</source>
        <extracomment>This text is the title of an openfile dialog.</extracomment>
        <translation>Fájlok kiválasztása</translation>
    </message>
    <message>
        <source>Multimedia</source>
        <translation>Multimédia</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Videó</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audió</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Minden fájl</translation>
    </message>
    <message>
        <source>Select Directory</source>
        <extracomment>This text is the title of an open directory dialog.</extracomment>
        <translation>Válasszon Könyvtárat</translation>
    </message>
    <message>
        <source>Searching for files...</source>
        <translation>Fájlok keresése...</translation>
    </message>
    <message>
        <source>Some files could not be found.</source>
        <translation>Néhány fájl nem található.</translation>
    </message>
    <message>
        <source>Folder does not exist. Create a new folder?</source>
        <translation>A mappa nem létezik. Létrehozza?</translation>
    </message>
    <message>
        <source>Failed to create folder. Please select another output folder.</source>
        <translation>Mappa létrehozása sikertelen. Válasszon másik kimeneti mappát.</translation>
    </message>
    <message>
        <source>Add Files</source>
        <translation>Fájlok Hozzáadása</translation>
    </message>
    <message>
        <source>Remove Selected</source>
        <translation>A kiválasztott eltávolítása</translation>
    </message>
    <message>
        <source>Clear List</source>
        <translation>Lista ürítése</translation>
    </message>
</context>
<context>
    <name>ConversionParameterDialog</name>
    <message>
        <source>Conversion Parameters</source>
        <translation>Átalakítási paraméterek</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audió</translation>
    </message>
    <message>
        <source>Disable Audio</source>
        <translation>Audió inaktív</translation>
    </message>
    <message>
        <source>Audio Options</source>
        <translation>Audió lehetőségek</translation>
    </message>
    <message>
        <source>Sample Rate</source>
        <translation>MIntavételezési ráta</translation>
    </message>
    <message>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <source>Bitrate</source>
        <translation>Bitráta</translation>
    </message>
    <message>
        <source>(auto)</source>
        <translation>(auto)</translation>
    </message>
    <message>
        <source>kb/s</source>
        <translation>kb/s</translation>
    </message>
    <message>
        <source>Channels</source>
        <translation>Csatornák</translation>
    </message>
    <message>
        <source>Volume</source>
        <translation>Hangerő</translation>
    </message>
    <message>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Videó</translation>
    </message>
    <message>
        <source>Disable Video</source>
        <translation>Inaktív videó</translation>
    </message>
    <message>
        <source>Video Options</source>
        <translation>Videó lehetőségek</translation>
    </message>
    <message>
        <source>Same Quantizer as Source</source>
        <translation>A forrásal megegyező kvantáló</translation>
    </message>
    <message>
        <source>Deinterlace</source>
        <translation>Váltottsorosság megszüntetése</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Szélesség</translation>
    </message>
    <message>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <source>Height</source>
        <translation>Magasság</translation>
    </message>
    <message>
        <source>Crop</source>
        <translation>Levágás</translation>
    </message>
    <message>
        <source>Time</source>
        <extracomment>time-related options (speed, length)</extracomment>
        <translation>Idő</translation>
    </message>
    <message>
        <source>Cutting</source>
        <extracomment>video time cutting: options for begin time and end time</extracomment>
        <translation>Vágás</translation>
    </message>
    <message>
        <source>Cut</source>
        <comment>Cut video; select a range to convert</comment>
        <translatorcomment>Vágott videó; válassza ki a konvertálni kívánt tartományt</translatorcomment>
        <translation>Vág</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>&amp;Előnézet</translation>
    </message>
    <message>
        <source>Scaling</source>
        <extracomment>time scaling, changing the speed of the output file</extracomment>
        <translation>Méretezés</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Sebesség</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Haladó</translation>
    </message>
    <message>
        <source>FFmpeg</source>
        <translation>FFmpeg</translation>
    </message>
    <message>
        <source>Additional FFmpeg Options</source>
        <translation>További FFmpeg lehetőségek</translation>
    </message>
    <message>
        <source>Copy Audio (Do not re-encode)</source>
        <translation>Hang másolása (ne újra kódolja)</translation>
    </message>
    <message>
        <source>Insert Subtitle if Available</source>
        <translation>Helyezze be a Felirat lehetőséget, ha rendelkezésre áll</translation>
    </message>
    <message>
        <source>Copy Video (Do not re-encode)</source>
        <translation>Videó másolása (ne újra kódolja)</translation>
    </message>
    <message>
        <source>qrc:/qml/main.qml</source>
        <translation></translation>
    </message>
    <message>
        <source>Video Extra Options</source>
        <translation>Videó extra opciói</translation>
    </message>
    <message>
        <source>Video to Black and White</source>
        <translation>Videó fekete-fehér</translation>
    </message>
    <message>
        <source>Vertical Flip</source>
        <translation>Fordítsa függőlegesen</translation>
    </message>
    <message>
        <source>Horizontal Flip</source>
        <translation>Fordítsa vízszintesen</translation>
    </message>
    <message>
        <source>Rotate 90 degrees clockwise</source>
        <translation>Forgassa 90 fokkal jobbra</translation>
    </message>
    <message>
        <source>Rotate 90 degrees counterclockwise</source>
        <translation>Forgassa 90 fokkal balra</translation>
    </message>
    <message>
        <source>Rotate 180 degrees</source>
        <translation>Forgassa el 180 fokkal</translation>
    </message>
    <message>
        <source>3D Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red Blue Gray Monochromatic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red Cyan Dubois</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Green Magenta Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red Cyan Half Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yellow Blue Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red Cyan Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Green Magenta Gray Monochromatic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red Green Gray Monochromatic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConvertList</name>
    <message>
        <source>Cancel</source>
        <extracomment>Cancel the operation of adding new tasks</extracomment>
        <translation>Mégsem</translation>
    </message>
    <message>
        <source>Adding files (%1/%2)</source>
        <extracomment>This text is the progress indicator of adding multiple tasks. %1 is the number of files that are already added. %2 is the total number of files.</extracomment>
        <translation>Fájlok hozzáadása (%1/%2)</translation>
    </message>
    <message>
        <source>Some files are not recognized by the converter.</source>
        <translation>Néhány fájl az átalakító számára nem felismerhető.</translation>
    </message>
    <message>
        <source>New File Name</source>
        <translation>Új fájlnév</translation>
    </message>
    <message>
        <source>Please input the new name for the output file.</source>
        <translation>Adjon meg új nevet a kimeneti fájlnak.</translation>
    </message>
    <message>
        <source>Output Directory</source>
        <translation>Kimeneti könyvtár</translation>
    </message>
    <message>
        <source>Error Message from FFmpeg:

</source>
        <translation>FFmpeg hibaüzenet:

</translation>
    </message>
    <message>
        <source>Drag and drop files here to add tasks.</source>
        <translation>Húzzon ide fájlokat a feladatok hozzáadásához.</translation>
    </message>
    <message>
        <source>Hide &quot;%1&quot;</source>
        <extracomment>Hide a column in the list. For example, the text maybe &apos;Hide &quot;Duration&quot;&apos;. The two &quot; are quotation marks in English, you may replace it with local quotation marks.</extracomment>
        <translation>&quot;%1&quot; elrejtése</translation>
    </message>
    <message>
        <source>Restore All Columns</source>
        <translation>Összes oszlop visszaállítása</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Forrás</translation>
    </message>
    <message>
        <source>Destination</source>
        <translation>Cél</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Időtartam</translation>
    </message>
    <message>
        <source>File Size</source>
        <translation>Fájl mérete</translation>
    </message>
    <message>
        <source>Sample Rate</source>
        <extracomment>Audio</extracomment>
        <translation>MIntavételezési ráta</translation>
    </message>
    <message>
        <source>Audio Bitrate</source>
        <translation>Audió bitráta</translation>
    </message>
    <message>
        <source>Channels</source>
        <extracomment>Audio</extracomment>
        <translation>Csatornák</translation>
    </message>
    <message>
        <source>Audio Codec</source>
        <translation>Audió kodek</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Méret</translation>
    </message>
    <message>
        <source>Video Bitrate</source>
        <translation>Videó bitráta</translation>
    </message>
    <message>
        <source>Framerate</source>
        <extracomment>Video</extracomment>
        <translation>Képkockák</translation>
    </message>
    <message>
        <source>Video Codec</source>
        <translation>Videó kodek</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>Folyamat</translation>
    </message>
    <message>
        <source>%1 Hz</source>
        <translation>%1 Hz</translation>
    </message>
    <message>
        <source>%1 kb/s</source>
        <translation>%1 kb/s</translation>
    </message>
    <message>
        <source>%1 fps</source>
        <translation>%1 fps</translation>
    </message>
    <message>
        <source>Removing tasks...</source>
        <extracomment>Remove files from the tasklist</extracomment>
        <translation>Feladat eltávolítása...</translation>
    </message>
    <message>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <source>MiB</source>
        <translation>MiB</translation>
    </message>
    <message>
        <source>GiB</source>
        <translation>GiB</translation>
    </message>
    <message>
        <source>TiB</source>
        <translation>TiB</translation>
    </message>
    <message>
        <source>B</source>
        <extracomment>Bytes</extracomment>
        <translation>B</translation>
    </message>
    <message>
        <source>File Exists</source>
        <translation>Létező fájl</translation>
    </message>
    <message>
        <source>%1 already exists on disk or in the task list. Still use this name as the output filename?</source>
        <translation>A(z) %1 már létezik a lemezen vagy a feladatlistában.  Továbbra is ezt használjha kimeneti fájlnévként?</translation>
    </message>
    <message>
        <source>Remove Task</source>
        <translation>Feladat eltávolítása</translation>
    </message>
    <message>
        <source>Cannot remove a task while it is in progress.</source>
        <translation>Folyamatban lévő feladat nem távolítható el!.</translation>
    </message>
    <message>
        <source>Finished</source>
        <extracomment>The text to be displayed on the progress bar when a conversion finishes</extracomment>
        <translation>Befejezve</translation>
    </message>
    <message>
        <source>Failed</source>
        <extracomment>The text to be displayed on the progress bar when a conversion fails</extracomment>
        <translation>Sikertelen</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <extracomment>%1 is the error message</extracomment>
        <translation>Hiba :%1</translation>
    </message>
</context>
<context>
    <name>ExtraTranslations</name>
    <message>
        <source>Convert between media file formats</source>
        <translation>Média fájlformátumok átalakítása</translation>
    </message>
    <message>
        <source>Media Converter</source>
        <translation>Média átalakító</translation>
    </message>
</context>
<context>
    <name>HelpMystiQDialog</name>
    <message>
        <source>User Manual</source>
        <translation>Használati Utasítás</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Fira Sans&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:18pt; font-weight:600;&quot;&gt;MystiQ User&apos;s Manual&lt;/span&gt;&lt;/p&gt;
&lt;hr /&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/app/icons/mystiq_96x96.png&quot; style=&quot;float: left;&quot; /&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;MystiQ Video Converter is a cross platform application. This application has as its sole objective the conversion of audio and video files to multiple formats. As a distinctive feature, MystiQ is an open source project, which means that the source code will always be available and everyone who wishes to contribute to the development is welcome.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;MystiQ Video Converter is free: you can redistribute it and / or modify it under the terms GNU (General Public License) published by the Free Software Foundation. MystiQ Video Converter is freely distributed with the sole purpose of being a useful application to your needs, but WITHOUT NO WARRANTY, even if its use is COMMERCIAL or MERELY A PARTICULAR PURPOSE See the GPL v3 license for more details. This application includes an English copy of the Software distribution license.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;The essential idea of ​​the development team is to provide a friendly and simple user interface. The simple is the essence of MystiQ, which means that it is not our objective to add features that complicate the operation of the application.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Currently MystiQ is mainly developed in C ++ taking advantage of the Qt5 graphic libraries. In the FFmpeg backend he is in charge of converting between formats, so we can say that MystiQ is simply a graphical interface for FFmpeg.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;MystiQ currently allows you to convert to most existing video formats, as well as make it possible to extract audio and convert between audio formats. It also includes a small tool to trim videos based on the duration of these.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;MystiQ Video Converter currently supports the following audio and video formats:&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;- Audio: mp3 m4a 3g2 ogg wav wma  ac3 ra ape flac opus&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;- Video: avi vfw divx mpg mpeg m1v m2v mpv dv 3gp mov mp4 m4v mqv dat vcd ogg ogm ogv asf wmv bin iso vob mkv nsv ram flv rm swf ts rmvb dvr-ms m2t m2ts rec mts webm dv&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/app/icons/screenshot1.png&quot; /&gt;&lt;/p&gt;
&lt;hr /&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;Toolbar&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;In the upper part of the main window of the application we will find the toolbar with the following buttons:&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/app/icons/screenshot2.png&quot; /&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;ul style=&quot;margin-top: 0px; margin-bottom: 0px; margin-left: 0px; margin-right: 0px; -qt-list-indent: 1;&quot;&gt;&lt;li style=&quot;&quot; style=&quot; margin-top:12px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Add Files:&lt;/span&gt; &lt;span style=&quot; font-size:12pt;&quot;&gt;Opens a dialog to select the video files you want to convert. Once selected, they are placed in the List of Conversion Tasks&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Start: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Start conversion process from the list of loaded items&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Stop: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Stops the process of converting an item&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Retry:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Retry the process of converting an item&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Retry All:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Retry the conversion process of all items in the list&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Remove Selected:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Remove a selected item from the list&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Remove Completed:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Remove all items from the list that have completed the conversion process&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Clear List:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Remove all items from the conversion list&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Open Output Folder: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;From the system file manager open the folder that contains the converted files&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot; font-size:12pt;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Power Options:&lt;/span&gt;&lt;span style=&quot; font-size:10pt;&quot;&gt;  &lt;/span&gt;Choose whether to shut down, suspend or hibernate the computer when completing the conversion process of all items in the list&lt;/li&gt;&lt;/ul&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;hr /&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;Audio Options&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/app/icons/screenshot3.png&quot; /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Disable Audio:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Allows you to obtain a resulting file excluding sound.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Copy audio (do not recode):&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Allows you to convert without processing the audio from the source file. The resulting file will have the same sound parameters as the source file.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Sample Rate:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; In audio production, a sample rate (or &amp;quot;sampling rate&amp;quot;) defines how many times per second a sound is sampled. Technically speaking, it is the frequency of samples used in a digital recording.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Bitrate:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; It&apos;s the bit rate or data that is processed per unit of time. The average bitrate for an MP3 file is 128 kbits per second or kbps.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Channels: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;It&apos;s the passage way a signal or data is transported. In case of audio files, it&apos;s the passage or communication channel in which a sound signal is transported from the player source to the speaker. An audio file can contain one, two or even more Channels.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Volume: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Allows you to configure the maximum volume of the destination file taking as a match the volume level of the source file.&lt;/span&gt;&lt;/p&gt;
&lt;hr /&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;Video Options&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/app/icons/screenshot4.png&quot; /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Insert Subtitle if Available: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;By checking this option, the application will verify if a subtitle file of the same name is found in the same location of the source file, if found, it will embed it in the resulting file. It is currently compatible with subtitles in SRT, SSA, ASS and SUB format.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Disable Video:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Allows you to obtain a resulting file excluding video.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;- &lt;/span&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Copy Video (Do not re-encode):&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Allows you to convert without processing the video from the source file. The resulting file will have the same video parameters as the source file.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Video to Black and White: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;It allows to obtain a video file is grayscale.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Flip and Rotate options: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;The resulting file will be rotated or flipped in the direction chosen.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;- &lt;/span&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Deinterlace: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;It&apos;s the process of converting interlaced video, such as common analog television signals or 1080i format HDTV signals, into a non-interlaced form. An interlaced video frame consists of two sub-fields taken in sequence, each sequentially scanned at odd, and then even, lines of the image sensor.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Same Quantizer as source: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;It&apos;s involved in image processing, is a lossy compression technique achieved by compressing a range of values to a single quantum value. Checking this option the resulting file will have the same deinterlacing as the source file.&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>InteractiveCuttingDialog</name>
    <message>
        <source>Cutting</source>
        <comment>Cutting as in &quot;cutting video&quot;</comment>
        <translation>Vágás</translation>
    </message>
    <message>
        <source>Mark as Begin</source>
        <translation>Jelölje meg kezdőnek</translation>
    </message>
    <message>
        <source>Seek to Begin</source>
        <translation>Keresse meg</translation>
    </message>
    <message>
        <source>Play Selection</source>
        <translation>Play Selection</translation>
    </message>
    <message>
        <source>Mark as End</source>
        <translation>Megjelölés végeként</translation>
    </message>
    <message>
        <source>Seek to End</source>
        <translation>Keresse a végét</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Start conversion process.</source>
        <translation>Átalakítás indítása.</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fájl</translation>
    </message>
    <message>
        <source>&amp;Convert</source>
        <translation>&amp;Átalakítás</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Szerkesztés</translation>
    </message>
    <message>
        <source>&amp;Add Files</source>
        <translation>&amp;Fájlok Hozzáadása</translation>
    </message>
    <message>
        <source>Add files for conversion.</source>
        <translation>Fájlok hozzáadása átalakításhoz.</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Kilépés</translation>
    </message>
    <message>
        <source>Exit the program.</source>
        <translation>Kilépés a programból.</translation>
    </message>
    <message>
        <source>S&amp;top</source>
        <translation>Á&amp;llj</translation>
    </message>
    <message>
        <source>Stop conversion process.</source>
        <translation>Átalakításai folymat megállítása.</translation>
    </message>
    <message>
        <source>Set &amp;Parameters</source>
        <translation>Változók &amp;beállítása</translation>
    </message>
    <message>
        <source>Set Parameters</source>
        <extracomment>Edit output file parameters.</extracomment>
        <translation>Kimeneti változók beállítása</translation>
    </message>
    <message>
        <source>Edit conversion parameters of selected files.</source>
        <translation>A kiválasztott fájlok átalakítási változóinak beállítása.</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>A &amp;Qt-ről</translation>
    </message>
    <message>
        <source>About Qt</source>
        <translation>A Qt-ről</translation>
    </message>
    <message>
        <source>&amp;Open Output Folder</source>
        <translation>&amp;Kimeneti könyvtár megnyitása</translation>
    </message>
    <message>
        <source>Open output folder of the selected file.</source>
        <translation>A kiválasztott fájl kimeneti mappájának megnyitása.</translation>
    </message>
    <message>
        <source>About &amp;FFmpeg</source>
        <translation>Az &amp;FFmpeg-ről</translation>
    </message>
    <message>
        <source>About FFmpeg</source>
        <translation>Az FFmpeg-ről</translation>
    </message>
    <message>
        <source>&amp;Remove Selected</source>
        <extracomment>remove selected (tasks, items)</extracomment>
        <translation>&amp;Kiválasztottak eltávolítása</translation>
    </message>
    <message>
        <source>Remove all selected items in the list.</source>
        <translation>Minden kiválasztott elem eltávolítása a listáról.</translation>
    </message>
    <message>
        <source>R&amp;emove Completed</source>
        <extracomment>remove completed (task, items)</extracomment>
        <translatorcomment>eltávolítás befejezve (feladat, tételek)</translatorcomment>
        <translation>&amp;Eltávolítás befejezve</translation>
    </message>
    <message>
        <source>Remove Completed Items</source>
        <translation>Elkemek eltávolítása befejezve</translation>
    </message>
    <message>
        <source>Remove all completed items in the list.</source>
        <translation>Az összes elkészült elem eltávolítása a listáról.</translation>
    </message>
    <message>
        <source>Clear List</source>
        <translation>Lista ürítése</translation>
    </message>
    <message>
        <source>Remove all items in the list.</source>
        <translation>Minden listán lévő elem eltávolítása.</translation>
    </message>
    <message>
        <source>&amp;Retry</source>
        <translation>&amp;Újra</translation>
    </message>
    <message>
        <source>Retry</source>
        <translation>Újra</translation>
    </message>
    <message>
        <source>Retry selected tasks.</source>
        <translation>Kiválasztott feladatok újrapróbálása.</translation>
    </message>
    <message>
        <source>Retry &amp;All</source>
        <translation>Újra &amp;mindet</translation>
    </message>
    <message>
        <source>Retry all tasks.</source>
        <translation>Minden feladat újrapróbálása.</translation>
    </message>
    <message>
        <source>&amp;Options</source>
        <translation>&amp;Opciók</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opciók</translation>
    </message>
    <message>
        <source>About This Program</source>
        <translation>Erről a programról</translation>
    </message>
    <message>
        <source>Change Output &amp;Filename</source>
        <translation>Kimeneti fájlnév &amp;megváltoztatása</translation>
    </message>
    <message>
        <source>Change the output filename of the selected item.</source>
        <translation>Kiválasztott elemek kimeneti fájlnevének megváltoztatása.</translation>
    </message>
    <message>
        <source>Change Output &amp;Directory</source>
        <translation>Kimeneti könyvtár me&amp;gváltoztatása</translation>
    </message>
    <message>
        <source>Change the output directory of the selected items.</source>
        <translation>Kiválasztott elemek kimeneti könytárának megváltoztatása.</translation>
    </message>
    <message>
        <source>Show Error &amp;Message</source>
        <translation>Hibaüzenetek meg&amp;jelenítése</translation>
    </message>
    <message>
        <source>Check For &amp;Updates</source>
        <translation>Frissítések elle&amp;nőrzése</translation>
    </message>
    <message>
        <source>Cut</source>
        <extracomment>Cut video file (select a time range to conert)</extracomment>
        <translatorcomment>Videofájl kivágása (válasszon egy időtartamot a megerősítéshez)</translatorcomment>
        <translation>Vág</translation>
    </message>
    <message>
        <source>All tasks have finished.</source>
        <translation>Minden feladat befejeződött.</translation>
    </message>
    <message>
        <source>Nothing to convert.</source>
        <translation>Nincs mit átalakítani.</translation>
    </message>
    <message>
        <source>Conversion is still in progress. Abort?</source>
        <translation>Átalakítás folymatban. Megszakítja?</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <extracomment>Shutdown the computer (completely poweroff)</extracomment>
        <translation>Leállítás</translation>
    </message>
    <message>
        <source>Shutdown when all tasks are done.</source>
        <translation>Leállítás ha minden feladat befejeződött.</translation>
    </message>
    <message>
        <source>Suspend</source>
        <extracomment>Suspend the computer (sleep to ram, standby)</extracomment>
        <translation>Felfüggesztés</translation>
    </message>
    <message>
        <source>Suspend when all tasks are done.</source>
        <translation>Felfüggesztés ha minden feladat befejeződött.</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <extracomment>Hibernate the computer (sleep to disk, completely poweroff)</extracomment>
        <translation>Hibernálás</translation>
    </message>
    <message>
        <source>Hibernate when all tasks are done.</source>
        <translation>Hibernálás ha minden feladat befejeződött.</translation>
    </message>
    <message>
        <source>This program is going to check for updates online. Do you allow this program to use the Internet to check for updates?</source>
        <translation>A program ellenőrzi a frissítéseket, ehhez az internet kapcsolatot használja. Engedélyezi az internet hozzáférést a program számára?</translation>
    </message>
    <message>
        <source>Failed to load preset file. The application will quit now.</source>
        <translation>Nem sikerült betölteni az előbeállító fájlt. Az alkalmazás most kilép.</translation>
    </message>
    <message>
        <source>Elapsed Time: %1 h %2 m %3 s</source>
        <translation>Hátralévő idő: %1 ó %2 p %3 mp</translation>
    </message>
    <message>
        <source>MystiQ Media Converter</source>
        <translation></translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Segítség</translation>
    </message>
    <message>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <source>Clear &amp;List</source>
        <translation>Lista &amp;Törlése</translation>
    </message>
    <message>
        <source>About MystiQ</source>
        <translation>A MystiQ-ről</translation>
    </message>
    <message>
        <source>Poweroff</source>
        <translation>Kikapcsolni</translation>
    </message>
    <message>
        <source>User Manual</source>
        <translation>Használati Utasítás</translation>
    </message>
    <message>
        <source>F1</source>
        <translation>F1</translation>
    </message>
    <message>
        <source>&amp;Report Error</source>
        <translation>&amp;Hibajelentés</translation>
    </message>
    <message>
        <source>Report Error</source>
        <translation>Hibajelentés</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation></translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Adományoz</translation>
    </message>
    <message>
        <source>Conversion finished successfully.</source>
        <translation>Az átalakítás sikeresen befejeződött.</translation>
    </message>
    <message>
        <source>Conversion failed.</source>
        <translation>Az átalakítás sikertelen.</translation>
    </message>
    <message>
        <source>Support MystiQ</source>
        <translation>Támogassa a MystiQ-t</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zárja be az alkalmazást</translation>
    </message>
    <message>
        <source>MystiQ needs you</source>
        <translation>A MystiQ-nek szüksége van rád</translation>
    </message>
    <message>
        <source>MystiQ is free software. However the development requires a lot of time and a lot of work. In order to keep developing MystiQ with new features we need your help. Please consider to support the MystiQ project by sending a donation. &lt;b&gt;Even the smallest amount will help a lot.&lt;/b&gt;</source>
        <translation>A MystiQ egy ingyenes szoftver. A fejlesztés azonban sok időt és munkát igényel. A MystiQ új funkciókkal történő továbbfejlesztése érdekében segítségre van szüksége. Kérjük, fontolja meg a MystiQ projekt támogatását egy adomány elküldésével. &lt;b&gt; Még a legkisebb összeg is sokat segít. &lt;/b&gt;</translation>
    </message>
    <message>
        <source>Reporting bugs from MystiQ </source>
        <translation>Hibajelentés a MystiQ-tól </translation>
    </message>
    <message>
        <source>%1</source>
        <translation></translation>
    </message>
    <message>
        <source>Your comment:</source>
        <translation>A te hozzászólásod:</translation>
    </message>
    <message>
        <source>Report:</source>
        <translation>Feljelent:</translation>
    </message>
    <message>
        <source>MystiQ is Converting %1/%2</source>
        <extracomment>Converting the %1-th file in %2 files. %2 is the number of files.</extracomment>
        <translatorcomment>A (z) %1-es fájl konvertálása %2 fájlba. %2 a fájlok száma.</translatorcomment>
        <translation>A MystiQ konvertálja a %1/%2 fájlt</translation>
    </message>
    <message>
        <source>MystiQ Video Converter</source>
        <translation></translation>
    </message>
    <message>
        <source>Translate</source>
        <translation>Fordít</translation>
    </message>
    <message>
        <source>Translate Application</source>
        <translation>Alkalmazás Fordítása</translation>
    </message>
    <message>
        <source>Report Bugs</source>
        <translation>Jelentés a hibákról</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>Email</translation>
    </message>
    <message>
        <source>We need your feedback</source>
        <translation>Szüksége van visszajelzésre</translation>
    </message>
    <message>
        <source>Github</source>
        <translation>Github</translation>
    </message>
    <message>
        <source>MystiQ Video Converter development team needs users who use the application to help detect errors. If you find an error and report it to our team, it will help speed up the correction process. Therefore, you can be part of our development team even if you are not a developer. To report an error, you can send us an email with the detailed description of it or you can enter Github and describe the issue (in this case you must have a GitHub Account).</source>
        <translation>A MystiQ Video Converter fejlesztői csapatának olyan felhasználókra van szüksége, akik az alkalmazást használják a hibák észlelésére. Ha hibát talál, és jelentést tesz a csapatunknak, ez elősegíti a javítási folyamat felgyorsítását. Ezért akkor is részt vehet a fejlesztői csapatunkban, ha nem fejlesztő. Hiba jelentése érdekében e-mailt küldhet nekünk a hiba részletes leírásáról, vagy beléphet a Githubba, és leírhatja a problémát (ebben az esetben rendelkeznie kell GitHub fiókkal).</translation>
    </message>
    <message>
        <source>Gitter</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MediaConverter</name>
    <message>
        <source> FFmpeg or FFprobe %1 have not been found in the system. Please consider installing them before running MystiQ</source>
        <extracomment>%1 is a computer program</extracomment>
        <translation></translation>
    </message>
</context>
<context>
    <name>MediaPlayerWidget</name>
    <message>
        <source>...</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Opciók</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Általános</translation>
    </message>
    <message>
        <source>Check for updates on program startup</source>
        <translation>Frissítések keresése a program indulásakor</translation>
    </message>
    <message>
        <source>Automatically start conversion after adding files to the list.</source>
        <translation>Átalakítás automatikus indítása a fájlok hozzáadása után.</translation>
    </message>
    <message>
        <source>Start conversion automatically</source>
        <translation>Átalakítás automatikus indítása</translation>
    </message>
    <message>
        <source>FFmpeg</source>
        <translation>FFmpeg</translation>
    </message>
    <message>
        <source>Number of threads to use in conversion</source>
        <translation>Konvertálási szálak száma</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Hide output formats that are not available in the current ffmpeg installation. It is recommended to turn this option on unless you are sure that MystiQ has failed to detect available formats. (requires restarting MystiQ to take effect)&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Elrejti az FFmpeg jelenlegi telepítésében nem elérhető kimeneti fájlokat. Ajánlott ezt a lehetőséget bekapcsolni, kivéve, ha biztos benne, hogy a MystiQ nem ismerte fel a kimeneti formátumokat. (A MystiQ újraindítása szükséges a változtatás érvényesítéséhez)&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Hide unavailable formats (requires restarting)</source>
        <translation>Nem elérhető formátumok elrejtése (újraindítást igényel)</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Eszközök</translation>
    </message>
    <message>
        <source>You have to restart MystiQ for the changes to take effect.</source>
        <translation>Újra kell indítania a QWinff-et a változtatások érvényesítéséhez.</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Név</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Parancs</translation>
    </message>
</context>
<context>
    <name>PoweroffDialog</name>
    <message>
        <source>MystiQ</source>
        <translation>MystiQ</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Mégsem</translation>
    </message>
    <message>
        <source>Shutdown immediately</source>
        <extracomment>Shutdown the computer</extracomment>
        <translation>Azonnali leállítás</translation>
    </message>
    <message>
        <source>Suspend immediately</source>
        <extracomment>Suspend the computer (sleep to ram, standby)</extracomment>
        <translation>Azonnali felfüggesztés</translation>
    </message>
    <message>
        <source>Hibernate immediately</source>
        <extracomment>Hibernate the computer (sleep to disk, completely poweroff)</extracomment>
        <translation>Azonnali hibernálás</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <extracomment>Shutdown the computer</extracomment>
        <translation>Leállítás</translation>
    </message>
    <message>
        <source>Suspend</source>
        <extracomment>Suspend the computer (sleep to ram, standby)</extracomment>
        <translation>Felfüggesztés</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <extracomment>Hibernate the computer (sleep to disk, completely poweroff)</extracomment>
        <translation>Hibernálás</translation>
    </message>
    <message>
        <source>Operation Failed: %1</source>
        <translation>%1 művelet sikertelen</translation>
    </message>
    <message>
        <source>Shutting down in &lt;b&gt;%1&lt;/b&gt; seconds</source>
        <translation>Leállítás  &lt;b&gt;%1 másoperc&lt;/b&gt; múlva</translation>
    </message>
    <message>
        <source>Suspending in &lt;b&gt;%1&lt;/b&gt; seconds</source>
        <translation>Felfüggesztés &lt;b&gt;%1 másoperc&lt;/b&gt; múlva</translation>
    </message>
    <message>
        <source>Hibernating in &lt;b&gt;%1&lt;/b&gt; seconds</source>
        <translation>Hibernálás &lt;b&gt;%1 másoperc&lt;/b&gt; múlva</translation>
    </message>
</context>
<context>
    <name>PreviewDialog</name>
    <message>
        <source>Play Selected Range</source>
        <translation>Játsszon a kiválasztott tartományban</translation>
    </message>
    <message>
        <source>Begin</source>
        <extracomment>noun, the beginning of the video</extracomment>
        <translation>Kezdődik</translation>
    </message>
    <message>
        <source>End</source>
        <extracomment>noun, the end of the video</extracomment>
        <translation>Vége</translation>
    </message>
    <message>
        <source>Play %1~%2</source>
        <extracomment>play the video from time %1 to time %2. %1 and %2 are time in hh:mm:ss format.</extracomment>
        <translatorcomment>a videó lejátszása %1-től %2-ig. %1 és %2 idő hh: mm: ss formátumban.</translatorcomment>
        <translation>Játssz %1~%2</translation>
    </message>
    <message>
        <source>Video Preview</source>
        <translation>Videó előnézete</translation>
    </message>
</context>
<context>
    <name>TimeRangeEdit</name>
    <message>
        <source>From Begin</source>
        <translation>Elejétől</translation>
    </message>
    <message>
        <source>To End</source>
        <translation>Végéig</translation>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <source>Show &amp;Release Notes</source>
        <translation>Kiadási &amp;Megjegyzések</translation>
    </message>
    <message>
        <source>Check for updates on program startup</source>
        <translation>Frissítések keresése a program indításakor</translation>
    </message>
    <message>
        <source>Downloading update information...</source>
        <translation>Frissítési információk letöltése...</translation>
    </message>
    <message>
        <source>Cannot connect to server.</source>
        <translation>Nem lehet kapcsolódni a kiszolgálóhoz.</translation>
    </message>
    <message>
        <source>Failed to parse the received data.</source>
        <translation>A fogadott adatok elemzése sikertelen.</translation>
    </message>
    <message>
        <source>You are already using the latest version of MystiQ.</source>
        <translation>Már a MystiQ legújabb kiadását használja.</translation>
    </message>
    <message>
        <source>An unknown error has occurred.</source>
        <translation>Ismeretlen hiba!.</translation>
    </message>
    <message>
        <source>A new version of MystiQ has been released!</source>
        <translation>A MystiQ új kiadása elérhető!</translation>
    </message>
    <message>
        <source>Version &lt;b&gt;%1&lt;/b&gt; is available at %2.</source>
        <extracomment>%1 is version number, %2 is the project homepage</extracomment>
        <translatorcomment>%1 verziószám, %2 a projekt honlapja</translatorcomment>
        <translation>A &lt;b&gt;%1&lt;/b&gt; kiadás elérhető itt: %2.</translation>
    </message>
    <message>
        <source>You can download this version using the link:</source>
        <translation>Ezt a kiadást letöltheti az alábbi linken:</translation>
    </message>
    <message>
        <source>Check Update</source>
        <translation>Frissítés Ellenőrzése</translation>
    </message>
    <message>
        <source>The current version you are using is newer than the release channel version.&lt;br&gt;Therefore, you are using the development channel.</source>
        <translation>A jelenleg használt verzió újabb, mint a kiadási csatorna verziója.&lt;br&gt;Ezért használja a fejlesztési csatornát.</translation>
    </message>
</context>
</TS>
